@@ -62,7 +62,6 @@ static gboolean     gail_combo_remove_selection        (AtkSelection   *selectio
 static gint         _gail_combo_button_release         (gpointer       data);
 static gint         _gail_combo_popup_release          (gpointer       data);
 
-static gboolean     _gail_combo_is_entry_editable      (GtkWidget      *entry);
 
 static gpointer parent_class = NULL;
 
@@ -133,6 +132,7 @@ gail_combo_object_init (GailCombo      *combo)
   combo->press_description = NULL;
   combo->old_selection = NULL;
   combo->deselect_idle_handler = 0;
+  combo->select_idle_handler = 0;
 }
 
 AtkObject* 
@@ -190,6 +190,19 @@ notify_deselect (gpointer data)
   combo = GAIL_COMBO (data);
 
   combo->old_selection = NULL;
+  combo->deselect_idle_handler = 0;
+  g_signal_emit_by_name (data, "selection_changed");
+  return FALSE;
+}
+
+static gboolean
+notify_select (gpointer data)
+{
+  GailCombo *combo;
+
+  combo = GAIL_COMBO (data);
+
+  combo->select_idle_handler = 0;
   g_signal_emit_by_name (data, "selection_changed");
   return FALSE;
 }
@@ -216,7 +229,8 @@ gail_combo_selection_changed_gtk (GtkWidget      *widget,
       if (slist->data != gail_combo->old_selection)
         {
           gail_combo->old_selection = slist->data;
-          g_signal_emit_by_name (obj, "selection_changed");
+          if (gail_combo->select_idle_handler == 0)
+            gail_combo->select_idle_handler =  g_idle_add (notify_select, gail_combo);
         }
       if (gail_combo->deselect_idle_handler)
         {
@@ -228,27 +242,21 @@ gail_combo_selection_changed_gtk (GtkWidget      *widget,
     {
       if (gail_combo->deselect_idle_handler == 0)
         gail_combo->deselect_idle_handler =  g_idle_add (notify_deselect, gail_combo);
+      if (gail_combo->select_idle_handler)
+        {
+          g_source_remove (gail_combo->select_idle_handler);
+          gail_combo->select_idle_handler = 0;       
+        }
     }
 }
 
-static gboolean
-_gail_combo_is_entry_editable (GtkWidget       *entry)
-{
-  GValue value = { 0, };
-
-  g_value_init (&value, G_TYPE_BOOLEAN);
-  g_object_get_property (G_OBJECT (entry), "editable", &value);
-  return g_value_get_boolean (&value);
-}
-
 /*
  * The children of a GailCombo are the list of items and the entry field
- * if it is editable.
  */
 static gint
 gail_combo_get_n_children (AtkObject* obj)
 {
-  gint n_children = 1;
+  gint n_children = 2;
   GtkWidget *widget;
 
   g_return_val_if_fail (GAIL_IS_COMBO (obj), 0);
@@ -260,9 +268,6 @@ gail_combo_get_n_children (AtkObject* obj)
      */
     return 0;
 
-  if (_gail_combo_is_entry_editable (GTK_COMBO (widget)->entry))
-    n_children++;
-
   return n_children;
 }
 
@@ -287,10 +292,8 @@ gail_combo_ref_child (AtkObject *obj,
 
   if (i == 0)
     accessible = gtk_widget_get_accessible (GTK_COMBO (widget)->popup);
-  else if (_gail_combo_is_entry_editable (GTK_COMBO (widget)->entry))
+  else 
     accessible = gtk_widget_get_accessible (GTK_COMBO (widget)->entry);
-  else
-    return NULL;
 
   g_object_ref (accessible);
   return accessible;
@@ -675,5 +678,10 @@ gail_combo_finalize (GObject            *object)
       g_source_remove (combo->deselect_idle_handler);
       combo->deselect_idle_handler = 0;       
     }
+  if (combo->select_idle_handler)
+    {
+      g_source_remove (combo->select_idle_handler);
+      combo->select_idle_handler = 0;       
+    }
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
