@@ -238,6 +238,18 @@ gail_expander_get_name (AtkObject *obj)
 static gint
 gail_expander_get_n_children (AtkObject* obj)
 {
+  GtkWidget *widget;
+  GtkWidget *child;
+
+  widget = GTK_ACCESSIBLE (obj)->widget;
+
+  if (widget == NULL)
+    return 0;
+
+  child = GTK_BIN (widget)->child;
+  if (child && !GTK_IS_LABEL (child))
+    return 1; 
+
   return 0;
 }
 
@@ -245,6 +257,25 @@ static AtkObject*
 gail_expander_ref_child (AtkObject *obj,
                          gint      i)
 {
+  GtkWidget *widget;
+  GtkWidget *child;
+  AtkObject *child_obj;
+
+  widget = GTK_ACCESSIBLE (obj)->widget;
+
+  if (widget == NULL)
+    return NULL;
+
+  if (i != 0)
+    return NULL;
+    
+  child = GTK_BIN (widget)->child;
+  if (child && !GTK_IS_LABEL (child))
+    {
+      child_obj = gtk_widget_get_accessible (child);
+      return g_object_ref (child_obj);
+    }
+
   return NULL;
 }
 
