@@ -167,6 +167,7 @@ gail_util_add_global_event_listener (GSignalEmissionHook listener,
 
       g_strfreev (split_string);
     }
+
   return rc;
 }
 
@@ -566,7 +567,15 @@ configure_event_watcher (GSignalInvocationHint  *hint,
       widget->allocation.height == ((GdkEventConfigure *)event)->height)
     return TRUE;
 
-  signal_name = "resize";
+  if (widget->allocation.width != ((GdkEventConfigure *)event)->width ||
+      widget->allocation.height != ((GdkEventConfigure *)event)->height)
+    {
+      signal_name = "resize";
+    }
+  else
+    {
+      signal_name = "move";
+    }
 
   atk_obj = gtk_widget_get_accessible (widget);
   g_return_val_if_fail (GAIL_IS_WINDOW (atk_obj), FALSE);
