@@ -29,6 +29,7 @@ enum {
   DESTROY,
   MAXIMIZE,
   MINIMIZE,
+  MOVE,
   RESIZE,
   RESTORE,
   LAST_SIGNAL
@@ -180,6 +181,14 @@ gail_window_class_init (GailWindowClass *klass)
                   NULL, NULL,
                   g_cclosure_marshal_VOID__VOID,
                   G_TYPE_NONE, 0);
+  gail_window_signals [MOVE] =
+    g_signal_new ("move",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0, /* default signal handler */
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__VOID,
+                  G_TYPE_NONE, 0);
   gail_window_signals [RESIZE] =
     g_signal_new ("resize",
                   G_TYPE_FROM_CLASS (klass),
